package Foo;
use Function::Interface::Impl qw(IFoo);

fun foo() :Return() { }

1;
